@@ -1,6 +1,6 @@
 package Catmandu::PICA;
-#ABSTRACT: Catmandu modules for working with PICA data.
-our $VERSION = '0.06'; #VERSION
+#ABSTRACT: Catmandu modules for working with PICA+ data.
+our $VERSION = '0.07'; #VERSION
 
 
 1; # End of Catmandu::PICA
@@ -13,11 +13,17 @@ __END__
 
 =head1 NAME
 
-Catmandu::PICA - Catmandu modules for working with PICA data.
+Catmandu::PICA - Catmandu modules for working with PICA+ data.
 
 =head1 VERSION
 
-version 0.06
+version 0.07
+
+=head1 DESCRIPTION
+
+Catmandu::PICA provides methods to work with PICA+ data within the L<Catmandu>
+framework.  See L<Catmandu::Introduction> and L<http://librecat.org/> for an
+introduction into Catmandu.
 
 =head1 CATMANDU MODULES
 
@@ -25,16 +31,18 @@ version 0.06
 
 =item * L<Catmandu::Importer::PICA>
 
-=item * L<Catmandu::Importer::SRU::Parser::picaxml>
-
 =item * L<Catmandu::Exporter::PICA>
 
+=item * L<Catmandu::Importer::SRU::Parser::picaxml>
+
 =item * L<Catmandu::Fix::pica_map>
 
 =back
 
 =head1 INTERNAL MODULES
 
+The following modules may be renamed or removed in a future release.
+
 =over
 
 =item * L<PICA::Parser::XML>
@@ -51,26 +59,11 @@ version 0.06
 
 =back
 
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Catmandu::PICA
-
-You can also look for information at:
-
-    Catmandu
-        https://metacpan.org/module/Catmandu::Introduction
-        https://metacpan.org/search?q=Catmandu
-
-    LibreCat
-        http://librecat.org/tutorial/index.html
-
 =head1 CONTRIBUTORS
 
-Johann Rolschewski, C<< <rolschewski at gmail.com> >>
+Johann Rolschewski, <rolschewski@gmail.com>
 
-Jakob Voß C<< <voss at gbv.de> >>
+Jakob Voß <voss@gbv.de>
 
 =head1 AUTHOR
 
